@@ -68,10 +68,17 @@ class Metadata(object):
         if hasattr(method, 'request_schema'):
             request_schema = method.request_schema
             if hasattr(request_schema, 'querystring'):
+                optionals = request_schema.querystring_optionals()
                 for name, description in \
                         request_schema.describe_querystring.items():
-                    params.append(Param(
-                        name, style='querystring', description=description))
+                    params.append(
+                        Param(
+                            name,
+                            required=(not name in optionals),
+                            style='querystring',
+                            description=description
+                        )
+                    )
         return params
 
 
